/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.tellico.newstuff.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef NEWSTUFFADAPTOR_H
#define NEWSTUFFADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "manager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.tellico.newstuff
 */
class NewstuffAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.tellico.newstuff")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.tellico.newstuff\">\n"
"    <method name=\"installTemplate\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"result\"/>\n"
"    </method>\n"
"    <method name=\"removeTemplate\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"result\"/>\n"
"    </method>\n"
"    <method name=\"installScript\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"result\"/>\n"
"    </method>\n"
"    <method name=\"removeScript\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"result\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    NewstuffAdaptor(Tellico::NewStuff::Manager *parent);
    ~NewstuffAdaptor() override;

    inline Tellico::NewStuff::Manager *parent() const
    { return static_cast<Tellico::NewStuff::Manager *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool installScript(const QString &file);
    bool installTemplate(const QString &file);
    bool removeScript(const QString &file);
    bool removeTemplate(const QString &file);
Q_SIGNALS: // SIGNALS
};

#endif
